# Generated by Django 4.2.3 on 2023-07-09 20:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0006_alter_forum_author_names"),
    ]

    operations = [
        migrations.AlterField(
            model_name="post",
            name="response_count",
            field=models.PositiveIntegerField(default=0, editable=False),
        ),
    ]
